@@ -10,11 +10,11 @@ JSON::Any - Wrapper Class for the various JSON classes.
 
 =head1 VERSION
 
-Version 1.20
+Version 1.23
 
 =cut
 
-our $VERSION = '1.20';
+our $VERSION = '1.23';
 
 our $UTF8;
 
@@ -26,14 +26,47 @@ use constant UTF8    => 3;
 
 BEGIN {
     %conf = (
-        json => {
+        json_1 => {
+            encoder       => 'objToJson',
+            decoder       => 'jsonToObj',
+            get_true      => sub { return JSON::True(); },
+            get_false     => sub { return JSON::False(); },
+            create_object => sub {
+                require JSON;
+                my ( $self, $conf ) = @_;
+                my @params = qw(
+                    autoconv
+                    skipinvalid
+                    execcoderef
+                    pretty
+                    indent
+                    delimiter
+                    keysort
+                    convblessed
+                    selfconvert
+                    singlequote
+                    quoteapos
+                    unmapping
+                    barekey
+                );
+                my $obj = $handler->new( utf8 => $conf->{utf8} ); ## constructor only
+
+                for my $mutator (@params) {
+                    next unless exists $conf->{$mutator};
+                    $obj = $obj->$mutator( $conf->{$mutator} );
+                }
+
+                $self->[ENCODER] = 'objToJson';
+                $self->[DECODER] = 'jsonToObj';
+                $self->[HANDLER] = $obj;
+            },
+        },
+        json_2 => {
             encoder       => 'encode_json',
             decoder       => 'decode_json',
             get_true      => sub { return JSON::true(); },
             get_false     => sub { return JSON::false(); },
             create_object => sub {
-                require utf8;
-                utf8->import();
                 JSON->import( '-support_by_pp', '-no_export' );
                 my ( $self, $conf ) = @_;
                 my @params = qw(
@@ -123,11 +156,9 @@ BEGIN {
         json_xs_2 => {
             encoder       => 'encode_json',
             decoder       => 'decode_json',
-            get_true      => sub { return \1; },
-            get_false     => sub { return \0; },
+            get_true      => sub { return JSON::XS::true(); },
+            get_false     => sub { return JSON::XS::false(); },
             create_object => sub {
-                require utf8;
-                utf8->import();
                 my ( $self, $conf ) = @_;
 
                 my @params = qw(
@@ -184,7 +215,7 @@ BEGIN {
 sub _make_key {
     my $handler = shift;
     ( my $key = lc($handler) ) =~ s/::/_/g;
-    if ( 'json_xs' eq $key ) {
+    if ( 'json_xs' eq $key || 'json' eq $key ) {
         no strict 'refs';
         $key .= "_" . ( split /\./, ${"$handler\::VERSION"} )[0];
     }
@@ -512,6 +543,11 @@ sub jsonToObj {
     my $obj  = shift;
     croak 'must provide json to convert' unless defined $obj;
 
+    # some handlers can't parse single booleans (I'm looking at you DWIW)
+    if ( $obj =~ /^(true|false)$/ ) {
+        return $self->$1;
+    }
+
     if ( ref $self ) {
         my $method;
         unless ( ref $self->[DECODER] ) {
@@ -551,12 +587,17 @@ underlying JSON module.
 __END__
 
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Chris Thompson, C<< <cthom at cpan.org> >>
-Chris Prather, C<< <chris at prather.org> >>
-Robin Berjon, C<< robin at berjon.com >>
-Marc Mims C<<marc@questright.com>>
+Chris Thompson C<< cthom at cpan.org >>
+
+Chris Prather C<< chris at prather.org >>
+
+Robin Berjon C<< robin at berjon.com >>
+
+Marc Mims C<< marc at questright.com >>
+
+Tomas Doran C<< bobtfish at bobtfish.net >>
 
 =head1 BUGS
 
